Admin Tasks
-----------

Edit Properties Tab
```````````````````
This screen is used to configure how even properties are displayed in the
Alarms/Events Screen.

    **Value Map** - Displays the data stored in Peek for a Property.

    **Key** - The key of the Property from ADMS

    **Name** - The name Peek will display for a Property.

    **Order** - The order the property will be displayed in Peek.

    **Comment** - Creates a comment for a Property.

    **Filter Property** - Allows a Property to be filtered.

    **Popup Details** - Includes a property in the Info Popup.

    **Show on Summary** - TODO

    **Show on Detail** - TODO

    **Show filter as** - Selects the input type for the Property Filter.

To Edit the Properties
``````````````````````

#. Click on the Edit Properties Tab
#. Change the values of a Property in the Edit Properties Tab
#. Click Save

.. image:: edit_properties.png
    :align: center

General Settings
````````````````

There are currently no admin tasks to perform for General Settings